==> nextcloud-app-calendar-1.5.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/nl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s heeft de kalender gepubliceerd »%s«",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We willen je laten weten dat %s de kalender heeft gepubliceerd »%s«.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Proficiat!",
    "Recipient" : "Ontvanger",
    "Too many redirects. Aborting ..." : "Teveel doorverwijzingen. Afbreken ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "De externe server verleende geen toegang tot de agenda (HTTP {%s} fout)",
    "Error connecting to remote server" : "Fout bij het verbinden met de externe server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fout bij opvragen object op externe server. Dit kan te maken hebben met een onjuist certificaat",
    "Error requesting resource on remote server" : "Fout bij opvragen object op externe server.",
    "Individual" : "Individueel",
    "Group" : "Groep",
    "Resource" : "Bron",
    "Room" : "Ruimte",
    "Unknown" : "Onbekend",
    "Required" : "Vereist",
    "Optional" : "Optioneel",
    "Does not attend" : "Neemt niet deel",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "U bevindt zich in een onbekende tijdzone ({tz}), UTC zal worden gebruikt",
    "Please create a calendar first." : "Maak eerst een kalender aan",
    "New event" : "Nieuwe afspraak",
    "CalDAV address for clients" : "CalDAV adres voor clients",
    "Error saving WebCal-calendar" : "Fout bij opslaan WebCal agenda",
    "WebDAV address for subscriptions" : "WebDAV adres voor abonnementen",
    "Email has been sent." : "Email is verstuurd",
    "There was an issue while sending your email." : "Er was een probleem bij het versturen van je email.",
    "group" : "groep",
    "Details" : "Details",
    "Attendees" : "Deelnemers",
    "Reminders" : "Herinneringen",
    "Repeating" : "Herhaling",
    "When shared show full event" : "Wanneer gedeeld toon gehele gebeurtenis",
    "When shared show only busy" : "Wanneer gedeeld toon enkel beschikbaarheid",
    "When shared hide this event" : "Wanneer gedeeld verberg deze gebeurtenis",
    "Confirmed" : "Bevestigd",
    "Tentative" : "Voorlopig",
    "Cancelled" : "Geannuleerd",
    "Please add a title." : "Voeg een titel toe a.u.b.",
    "Please select a calendar." : "Selecteer een kalender a.u.b.",
    "The event can not end before it starts." : "De gebeurtenis kan niet eindigen voor het is begonnen.",
    "Global" : "Globaal",
    "None" : "Geen",
    "Every day" : "Iedere dag",
    "Every week" : "Iedere week",
    "Every month" : "Iedere maand",
    "Every year" : "Elk jaar",
    "never" : "geen",
    "after" : "na",
    "How about getting started by importing some calendars?" : "Zullen we beginnen met een paar agenda's te importeren?",
    "At time of event" : "Op de tijd van de afspraak",
    "5 minutes before" : "5 minuten vooraf",
    "10 minutes before" : "10 minuten vooraf",
    "15 minutes before" : "15 minuten vooraf",
    "30 minutes before" : "30 minuten vooraf",
    "1 hour before" : "1 uur vooraf",
    "2 hours before" : "2 uur vooraf",
    "Custom" : "Maatwerk",
    "Audio" : "Audio",
    "Email" : "Email",
    "Pop-up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "uur",
    "days" : "dagen",
    "week" : "week",
    "before" : "voor",
    "start" : "begint",
    "end" : "einde",
    "Editing reminders of unknown type not supported." : "Bewerken van herinneringen van onbekende types wordt niet ondersteund.",
    "Week {number} of {year}" : "Week {number} van {year}",
    "{type} {time} before the event starts" : "{type} {time} voor het begin van de afspraak",
    "{type} {time} before the event ends" : "{type} {time} voor het eind van de afspraak",
    "{type} {time} after the event starts" : "{type} {time} na het begin van de afspraak",
    "{type} {time} after the event ends" : "{type} {time} na het eind van de afspraak",
    "{type} at the event's start" : "{type} bij het begin van de afspraak",
    "{type} at the event's end" : "{type} bij het eind van de afspraak",
    "{type} at {time}" : "{type} om {time}",
    "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
    "Please enter a valid WebCal-URL" : "Voer een geldig WebCal-URL in",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Ernstige fout in webcal proxy. Neem contact op met de beheerder voor meer informatie.",
    "Title of the Event" : "Titel van de afspraak",
    "Starts" : "Beginnen",
    "Ends" : "Eindigt",
    "All day Event" : "Hele dag",
    "Delete" : "Verwijderen",
    "Cancel" : "Annuleren",
    "More ..." : "Meer...",
    "Create" : "Aanmaken",
    "Update" : "Bijwerken",
    "Close" : "Sluiten",
    "Location" : "Locatie",
    "Description" : "Beschrijving",
    "Event status" : "Afspraak status",
    "Visibility when sharing" : "Zichtbaarheid bij delen",
    "Export" : "Exporteer",
    "%s has published the calendar %s" : "%s publiceerde agenda %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "We willen je informeren dat %s agenda {boldstart}%s{boldend} heeft gepubliceerd.",
    "Click here to access it" : "Klik hier om er te komen",
    "We wanted to inform you that %s has published the calendar %s." : "We willen je informeren dat %s agenda %s heeft gepubliceerd.",
    "Click on the link below to access it" : "Klik op onderstaande link om er te komen",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "Today" : "Vandaag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Sommige afspraken in de agenda zijn kapot. Controleer de JS console voor meer info.",
    "Share Calendar" : "Delen agenda",
    "Shared" : "Gedeeld",
    "More" : "Meer",
    "Edit" : "Bewerk",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Downloaden",
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "can edit" : "kan wijzigen",
    "Share link" : "Delen link",
    "Public access" : "Openbare toegang",
    "Email link to person" : "Email link naar persoon",
    "Send" : "Versturen",
    "New Calendar" : "Nieuwe agenda",
    "Name" : "Naam",
    "New Subscription" : "Nieuw abonnement",
    "Go back" : "Ga terug",
    "Go forward" : "Ga verder",
    "Calendar does not exist" : "Agenda bestaat niet",
    "Maybe you got a wrong link or the calendar was unshared?" : "Kreeg je een verkeerde link of wordt de agenda niet gedeeld?",
    "Edit event" : "Bewerk gebeurtenis",
    "Delete Event" : "Verwijder afspraak",
    "Save Event" : "Bewaar afspraak",
    "Time" : "Tijd",
    "Type" : "Type",
    "Relative" : "Relatief",
    "Absolute" : "Absoluut",
    "Repeat" : "Herhaling",
    "times every" : "keer elke",
    "Add" : "Toevoegen",
    "Email address of attendee" : "Emailadres van deelnemer",
    "Please add your email address in the personal settings in order to add attendees." : "Stel je emailadres in in de accountinstellingen om aanwezigen toe te voegen.",
    "from" : "van",
    "to" : "naar",
    "This event's repeating rule is not supported yet." : "De herhaalregel van deze afspraak wordt nog niet ondersteund.",
    "Support for advanced rules will be added with subsequent updates." : "Ondersteuning voor geavanceerde regels wordt in toekomstige releases toegevoegd.",
    "Reset repeating rule" : "Herstel de herhaalregel",
    "Repeat every ..." : "Herhaal iedere ...",
    "end repeat ..." : "eind herhalen ...",
    "times" : "keer",
    "Import Calendars" : "Importeer agenda's",
    "Import canceled" : "Importeren geannuleerd",
    "Analyzing calendar" : "Analyseren agenda",
    "The file contains objects incompatible with the selected calendar" : "Het bestand bevat objecten die niet compatible zijn met de geselecteerde agenda",
    "New calendar" : "Nieuwe agenda",
    "File is empty" : "Bestand te leeg",
    "Import scheduled" : "Import ingepland",
    "%s shared the calendar <strong>%s</strong> with you" : "%s deelde agenda <strong>%s</strong> met jou",
    "Embed" : "Inbedden",
    "Iframe to integrate" : "Iframe integreert",
    "Publish URL" : "Publiceren URL",
    "Settings & import" : "Instellingen & importeren",
    "Skip simple event editor" : "Negeer simpele afsprakenbewerker",
    "Show week numbers" : "Tonen weeknummers",
    "Import calendar" : "Importeer agenda",
    "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
    "Primary CalDAV address" : "Primair CalDAV adres",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres",
    "Subscribe" : "Abonneren"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/nl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s heeft de kalender gepubliceerd »%s«",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We willen je laten weten dat %s de kalender heeft gepubliceerd »%s«.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Proficiat!",
    "Recipient" : "Ontvanger",
    "Too many redirects. Aborting ..." : "Teveel doorverwijzingen. Afbreken ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "De externe server verleende geen toegang tot de agenda (HTTP {%s} fout)",
    "Error connecting to remote server" : "Fout bij het verbinden met de externe server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fout bij opvragen object op externe server. Dit kan te maken hebben met een onjuist certificaat",
    "Error requesting resource on remote server" : "Fout bij opvragen object op externe server.",
    "Individual" : "Individueel",
    "Group" : "Groep",
    "Resource" : "Bron",
    "Room" : "Ruimte",
    "Unknown" : "Onbekend",
    "Required" : "Vereist",
    "Optional" : "Optioneel",
    "Does not attend" : "Neemt niet deel",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Je bevindt zich in een onbekende tijdzone ({tz}), UTC zal worden gebruikt",
    "Please create a calendar first." : "Maak eerst een kalender aan",
    "New event" : "Nieuwe afspraak",
    "CalDAV address for clients" : "CalDAV adres voor clients",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Sommige afspraken in de agenda zijn kapot. Controleer de JS console voor meer info.",
    "Share Calendar" : "Delen agenda",
    "Shared" : "Gedeeld",
    "WebDAV address for subscriptions" : "WebDAV adres voor abonnementen",
    "group" : "groep",
    "Details" : "Details",
    "Attendees" : "Deelnemers",
    "Reminders" : "Herinneringen",
    "Repeating" : "Herhaling",
    "When shared show full event" : "Wanneer gedeeld toon gehele gebeurtenis",
    "When shared show only busy" : "Wanneer gedeeld toon enkel beschikbaarheid",
    "When shared hide this event" : "Wanneer gedeeld verberg deze gebeurtenis",
    "Confirmed" : "Bevestigd",
    "Tentative" : "Voorlopig",
    "Cancelled" : "Geannuleerd",
    "Please add a title." : "Voeg een titel toe.",
    "Please select a calendar." : "Selecteer een kalender.",
    "The event can not end before it starts." : "De gebeurtenis kan niet eindigen voor het is begonnen.",
    "Global" : "Globaal",
    "None" : "Geen",
    "Every day" : "Iedere dag",
    "Every week" : "Iedere week",
    "Every month" : "Iedere maand",
    "Every year" : "Elk jaar",
    "never" : "geen",
    "after" : "na",
    "How about getting started by importing some calendars?" : "Zullen we beginnen met een paar agenda's te importeren?",
    "At time of event" : "Op de tijd van de afspraak",
    "5 minutes before" : "5 minuten vooraf",
    "10 minutes before" : "10 minuten vooraf",
    "15 minutes before" : "15 minuten vooraf",
    "30 minutes before" : "30 minuten vooraf",
    "1 hour before" : "1 uur vooraf",
    "2 hours before" : "2 uur vooraf",
    "Custom" : "Maatwerk",
    "Audio" : "Geluid",
    "Email" : "Email",
    "Pop-up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "uur",
    "days" : "dagen",
    "week" : "week",
    "before" : "voor",
    "start" : "begint",
    "end" : "einde",
    "Editing reminders of unknown type not supported." : "Bewerken van herinneringen van onbekende types wordt niet ondersteund.",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Successfully imported {imported} objects" : "Succesvol geïmporteerd {imported} objecten",
    "Imported {imported} out of {all}, skipped one duplicate" : "Geïmporteerd {imported} van {all}, één duplicaat overgeslagen",
    "Imported {imported} out of {all}, one failure" : "Geïmporteerd {imported} van {all}, één fout",
    "Imported {imported} out of {all}, {errors} failures" : "Geïmporteerd {imported} van {all}, {errors} fouten",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Geïmporteerd {imported} van {all}, overgeslagen {duplicates} duplicaten",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "GeïmImporteerd {imported} van {all}, {errors} fouten, overgeslagen {duplicates} duplicaten",
    "Audio alarm {time} before the event starts" : "Audio alarm {time} voor de afspraak begint",
    "Pop-up {time} before the event starts" : "Pop-up {time} voor de afspraak begint",
    "Email {time} before the event starts" : "E-mail {time} voor de afspraak begint",
    "None {time} before the event starts" : "Niets {time} voor de afspraak begint",
    "{type} {time} before the event starts" : "{type} {time} voor het begin van de afspraak",
    "Audio alarm {time} before the event ends" : "Audio alarm {time} voor de afspraak eindigt",
    "Pop-up {time} before the event ends" : "Pop-up {time} voor de afspraak eindigt",
    "Email {time} before the event ends" : "E-mail {time} voor de afspraak eindigt",
    "None {time} before the event ends" : "Niets {time} voor de afspraak eindigt",
    "{type} {time} before the event ends" : "{type} {time} voor het eind van de afspraak",
    "Audio alarm {time} after the event starts" : "Audio alarm {time} na begin van de afspraak",
    "Pop-up {time} after the event starts" : "Pop-up {time}  na begin van de afspraak",
    "Email {time} after the event starts" : "E-mail {time}  na begin van de afspraak",
    "None {time} after the event starts" : "Niets {time}  na begin van de afspraak",
    "{type} {time} after the event starts" : "{type} {time} na het begin van de afspraak",
    "Audio alarm {time} after the event ends" : "Audio alarm {time}  na eind van de afspraak",
    "Pop-up {time} after the event ends" : "Pop-up {time} na eind van de afspraak",
    "Email {time} after the event ends" : "E-mail {time} na eind van de afspraak",
    "None {time} after the event ends" : "Niets {time} na eind van de afspraak",
    "{type} {time} after the event ends" : "{type} {time} na het eind van de afspraak",
    "Audio alarm at the event's start" : "Audio-alarm bij begin van de afspraak",
    "Pop-up at the event's start" : "Pop-up bij begin van de afspraak",
    "Email at the event's start" : "E-mail bij begin van de afspraak",
    "None at the event's start" : "Niets bij begin van de afspraak",
    "{type} at the event's start" : "{type} bij het begin van de afspraak",
    "Audio alarm at the event's end" : "Audio alarm bij einde van de afspraak",
    "Pop-up at the event's end" : "Pop-up bij einde van de afspraak",
    "Email at the event's end" : "E-mail bij einde van de afspraak",
    "None at the event's end" : "Niets bij einde van de afspraak",
    "{type} at the event's end" : "{type} bij het eind van de afspraak",
    "Audio alarm at {time}" : "Audioalarm om {time}",
    "Pop-up at {time}" : "Pop-up om {time}",
    "Email at {time}" : "E-mail om {time}",
    "None at {time}" : "Niets om {time}",
    "{type} at {time}" : "{type} om {time}",
    "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
    "Please enter a valid WebCal-URL" : "Voer een geldig WebCal-URL in",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Ernstige fout in webcal proxy. Neem contact op met de beheerder voor meer informatie.",
    "Title of the Event" : "Titel van de afspraak",
    "Starts" : "Beginnen",
    "Ends" : "Eindigt",
    "All day Event" : "Hele dag",
    "Delete" : "Verwijderen",
    "Cancel" : "Annuleren",
    "More ..." : "Meer...",
    "Create" : "Aanmaken",
    "Update" : "Bijwerken",
    "Close" : "Sluiten",
    "Location" : "Locatie",
    "Description" : "Beschrijving",
    "Event status" : "Afspraak status",
    "Visibility when sharing" : "Zichtbaarheid bij delen",
    "Export" : "Exporteer",
    "%s has published the calendar %s" : "%s publiceerde agenda %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "We willen je informeren dat %s agenda {boldstart}%s{boldend} heeft gepubliceerd.",
    "Click here to access it" : "Klik hier om er te komen",
    "We wanted to inform you that %s has published the calendar %s." : "We willen je informeren dat %s agenda %s heeft gepubliceerd.",
    "Click on the link below to access it" : "Klik op onderstaande link om er te komen",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "Today" : "Vandaag",
    "More" : "Meer",
    "Edit" : "Bewerk",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Downloaden",
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "can edit" : "kan wijzigen",
    "Share link" : "Delen link",
    "Public access" : "Openbare toegang",
    "Email link to person" : "Email link naar persoon",
    "Send" : "Versturen",
    "New Calendar" : "Nieuwe agenda",
    "Name" : "Naam",
    "New Subscription" : "Nieuw abonnement",
    "Go back" : "Ga terug",
    "Go forward" : "Ga verder",
    "Calendar does not exist" : "Agenda bestaat niet",
    "Maybe you got a wrong link or the calendar was unshared?" : "Kreeg je een verkeerde link of wordt de agenda niet gedeeld?",
    "Edit event" : "Bewerk gebeurtenis",
    "Delete Event" : "Verwijder afspraak",
    "Save Event" : "Bewaar afspraak",
    "Time" : "Tijd",
    "Type" : "Type",
    "Relative" : "Relatief",
    "Absolute" : "Absoluut",
    "Repeat" : "Herhaling",
    "times every" : "keer elke",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-mail herinneringen zijn nog niet geïmplementeerd in de CalDAV server, er worden er dus geen verzonden.",
    "Add" : "Toevoegen",
    "Email address of attendee" : "Emailadres van deelnemer",
    "Please add your email address in the personal settings in order to add attendees." : "Stel je emailadres in in de accountinstellingen om aanwezigen toe te voegen.",
    "from" : "van",
    "to" : "naar",
    "This event's repeating rule is not supported yet." : "De herhaalregel van deze afspraak wordt nog niet ondersteund.",
    "Support for advanced rules will be added with subsequent updates." : "Ondersteuning voor geavanceerde regels wordt in toekomstige releases toegevoegd.",
    "Reset repeating rule" : "Herstel de herhaalregel",
    "Repeat every ..." : "Herhaal iedere ...",
    "end repeat ..." : "eind herhalen ...",
    "times" : "keer",
    "Import Calendars" : "Importeer agenda's",
    "Import canceled" : "Importeren geannuleerd",
    "Analyzing calendar" : "Analyseren agenda",
    "The file contains objects incompatible with the selected calendar" : "Het bestand bevat objecten die niet compatible zijn met de geselecteerde agenda",
    "New calendar" : "Nieuwe agenda",
    "File is empty" : "Bestand te leeg",
    "Import scheduled" : "Import ingepland",
    "%s shared the calendar <strong>%s</strong> with you" : "%s heeft de agenda <strong>%s</strong> met je gedeeld",
    "Embed" : "Inbedden",
    "Iframe to integrate" : "Iframe integreert",
    "Publish URL" : "Publiceren URL",
    "Settings & import" : "Instellingen & importeren",
    "Skip simple event editor" : "Negeer simpele afsprakenbewerker",
    "Show week numbers" : "Tonen weeknummers",
    "Import calendar" : "Importeer agenda",
    "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
    "Primary CalDAV address" : "Primair CalDAV adres",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres",
    "Subscribe" : "Abonneren"
},
"nplurals=2; plural=(n != 1);");
